# -*- coding: utf-8 -*-

from builtins import object
from django.db import models
from django.utils.translation import ugettext_lazy as _
from country_dialcode.intermediate_model_base_class import Model

prefix_type_list = ((0, "Landline"),
                    (1, "Mobile"),
                    (2, "NGN (Non Geographic Numbers)"))


# Create your models here.
class Country(Model):
    """
    Country

    These are the countries and their country code, country prefix, name
    For instance : USA, 1, United States
    """
    countrycode = models.CharField(max_length=3, verbose_name=_('ISO alpha-3'),
                                   help_text=_("Enter Country Code. e.g. USA - ISO alpha-3"))
    iso2 = models.CharField(verbose_name=_('ISO alpha-2'),
                            max_length=2, default='')
    countryprefix = models.IntegerField(verbose_name=_('Prefix'),
                                        help_text=_("Enter Country Prefix. e.g. 1"))
    countryname = models.CharField(max_length=240, verbose_name=_('Name'),
                                   help_text=_("Enter Country Name. e.g. United States"))

    class Meta(object):
        db_table = 'dialcode_country'
        verbose_name = _("country")
        verbose_name_plural = _("countries")

    def __unicode__(self):
        return "%s" % (self.countrycode)


class Prefix(Model):
    """
    Prefix

    These are the prefixes and destinations
    For instance : 44 ; United Kingdom
    """
    prefix = models.IntegerField(primary_key=True, help_text=_("enter prefix"))
    destination = models.CharField(max_length=180, help_text=_("enter destination"))
    country_id = models.ForeignKey(Country,
                                   db_column="country_id", null=True,
                                   blank=True, verbose_name=_("country code"),
                                   help_text=_("select country"), on_delete=models.CASCADE)
    carrier_name = models.CharField(max_length=180, help_text=_("enter carrier name"))
    prefix_type = models.IntegerField(choices=prefix_type_list, default=1,
                                      verbose_name=_('prefix type'),
                                      help_text=_("select prefix type"))

    class Meta(object):
        db_table = 'dialcode_prefix'
        verbose_name = _("prefix")
        verbose_name_plural = _("prefixes")
        ordering = ["prefix"]

    def __unicode__(self):
        return "%d" % (self.prefix)

    def country_name(self):
        """
        Return country name on country listing (changeview_list)
        """
        if self.country_id is None:
            return ""
        else:
            return self.country_id.countryname

    country_name.short_description = _("country name")



from past.builtins import basestring
import sys


PY2 = sys.version_info[0] == 2
if not PY2:
    text_type = str
    binary_type = bytes
    string_types = (str,)
    integer_types = (int,)
else:
    text_type = str
    binary_type = str
    string_types = basestring
    integer_types = (int, int)



# -*- coding: utf-8 -*-

from django import template
from django.template.defaultfilters import stringfilter
from django.utils.translation import gettext as _
from country_dialcode.models import Country
from country_dialcode.utils.isoflag import iso_flag as util_iso_flag

register = template.Library()


@stringfilter
def iso_flag(country_id, flag_path=u''):
    """
    Returns a full path to the ISO 3166-1 alpha-2 country code flag image.

    Example usage::

        {{ user_profile.country_dialcode.country_id|iso_flag }}

        {{ user_profile.country_dialcode.country_id|iso_flag:"appmedia/flags/%s.png" }}

    """
    if country_id == '999':
        # Added for internal call - ie flag/phone.png
        return util_iso_flag('telephone', flag_path)
    try:
        obj_country = Country.objects.get(id=country_id)
    except:
        return u''
    return util_iso_flag(obj_country.iso2, flag_path)


register.filter('iso_flag', iso_flag)


@stringfilter
def country_name(country_id):
    """
    Returns a country name

    >>> country_name(198)
    u'Spain'
    """
    if country_id == '999':
        # Added for internal call - ie flag/phone.png
        return _('internal call').title()
    try:
        obj_country = Country.objects.get(id=country_id)
        return obj_country.countryname
    except:
        return _('unknown').title()


register.filter('country_name', country_name)



# -*- coding: utf-8 -*-

from builtins import object
from django.db import models
from django.core.exceptions import ObjectDoesNotExist


class Model(models.Model):
    """
    Intermediate model base class.
    """
    class Meta(object):
        abstract = True

    def delete(self, *args, **kwargs):
        self.clear_nullable_related()
        super(Model, self).delete(*args, **kwargs)

    def clear_nullable_related(self):
        """
        Recursively clears any nullable foreign key fields on related objects.
        Django is hard-wired for cascading deletes, which is very dangerous for
        us. This simulates ON DELETE SET NULL behavior manually.
        """
        for related in self._meta.get_all_related_objects():
            accessor = related.get_accessor_name()
            try:
                related_set = getattr(self, accessor)
            except ObjectDoesNotExist:
                continue

            if related.field.null:
                related_set.clear()
            elif related.field.rel.multiple:
                for related_object in related_set.all():
                    related_object.clear_nullable_related()



# -*- coding: utf-8 -*-

from django.core.management import call_command
from django.test import TestCase
from country_dialcode.models import Country, Prefix


# class CountryDialcodeAdminView(TestCase):
#     """Test cases for CountryDialcode Admin Interface."""
#
#     def test_admin_country_view_list(self):
#         """Test Function to check admin country list"""
#         response = self.client.get("/admin/country_dialcode/country/")
#         self.assertEqual(response.status_code, 200)
#
#     def test_admin_country_view_add(self):
#         """Test Function to check admin country add"""
#         response = self.client.get("/admin/country_dialcode/country/add/")
#         self.assertEqual(response.status_code, 200)
#
#         response = self.client.post(
#             '/admin/country_dialcode/country/add/',
#             data={'countrycode': 'ESP',
#                   'iso2': 'ES',
#                   'countryprefix': '34',
#                   'countryname': 'Spain',
#                   }, follow=True)
#         self.assertEqual(response.status_code, 200)
#
#     def test_admin_prefix_view_list(self):
#         """Test Function to check admin prefix list"""
#         response = self.client.get("/admin/country_dialcode/prefix/")
#         self.assertEqual(response.status_code, 200)
#
#     def test_admin_prefix_view_add(self):
#         """Test Function to check admin prefix add"""
#         response = self.client.get("/admin/country_dialcode/prefix/add/")
#         self.assertEqual(response.status_code, 200)
#
#         response = self.client.post(
#             '/admin/country_dialcode/prefix/add/',
#             data={'prefix': '34',
#                   'destination': 'Spain',
#                   'country_id': 198,
#                   'carrier_name': 'xyz',
#                   'prefix_type': 1})
#         self.assertEqual(response.status_code, 200)


class CountryDialcodeModel(TestCase):
    """Test Country, Prefix models"""

    def setUp(self):
        # Country model
        self.country = Country(
            countrycode="ESP",
            iso2='ES',
            countryprefix='34',
            countryname='Spain',
        )
        self.country.save()
        self.assertEqual(self.country.__unicode__(), u'ESP')

        # Prefix model
        self.prefix = Prefix(
            prefix=34,
            destination='Spain',
            country_id=self.country,
            carrier_name='xyz',
            prefix_type=1
        )

        self.prefix.save()
        self.assertEqual(self.prefix.__unicode__(), u'34')

    def test_country_prefix_name(self):
        self.assertEqual(self.country.countryname, "Spain")
        self.assertEqual(self.prefix.country_name(), "Spain")

    def teardown(self):
        self.country.delete()
        self.prefix.delete()

    # def test_mgt_command(self):
    #     # Test mgt command
    #     call_command('load_country_dialcode')



from django.conf import settings


def iso_flag(iso, flag_path=u''):
    """
    Returns a full path to the ISO 3166-1 alpha-2 country code flag image.

    ``flag_path`` is given in the form
    ``'<path relative to media root>/%s.gif'``
    and is appended to ``settings.MEDIA_URL``

    if a valid flag_path is not given trys to use
    ``settings.COUNTRIES_FLAG_PATH``
    defaults to ``'flags/%s.gif'``

    """
    default = u'-'
    if not iso:
        iso = default
    else:
        iso = iso.lower().strip()
    try:
        flag_name = flag_path % iso
    except (ValueError, TypeError):
        flag_path = getattr(settings, 'COUNTRIES_FLAG_PATH', u'flags/%s.png')
        try:
            flag_name = flag_path % iso
        except (ValueError, TypeError):
            return u''
    return flag_name



# -*- coding: utf-8 -*-

from __future__ import print_function
from django.core.management.base import BaseCommand
from django.core.management import call_command
import inspect
import os


class Command(BaseCommand):
    args = ' '
    help = "Load Dial Code\n"

    def handle(self, *args, **options):
        """
        Load country dialcode
        """
        script_directory = os.path.dirname(
            inspect.getfile(inspect.currentframe()))
        fixture_file = script_directory + \
            '/../../fixtures/country_dialcode.json'
        print("This fixture is going to be loaded : " + fixture_file)
        call_command('loaddata', fixture_file)



# -*- coding: utf-8 -*-
#
# :description: Django reusable application to manage Dial code of Countries
#
# :copyright: (c) 2011-2014 Areski Belaid and individual contributors,
#                 All rights reserved.
# :license:   MIT, see MIT-LICENSE.txt for more details.
#

__version__ = '0.6.4'  # edit also docs/source/conf.py and update requirements.txt
__author__ = "Arezqui Belaid"
__contact__ = "areski@gmail.com"
__homepage__ = "http://www.areskibelaid.com"
__docformat__ = "restructuredtext"

default_app_config = 'country_dialcode.apps.CountryDialcodeConfig'



from django.contrib import admin
from country_dialcode.models import Country, Prefix


class CountryAdmin(admin.ModelAdmin):
    list_display = ('countrycode', 'iso2', 'countryprefix', 'countryname')
    search_fields = ('countryname', 'countryprefix')
    ordering = ('id', )
    list_filter = ['countryprefix', 'countrycode']

    def __init__(self, *args, **kwargs):
        super(CountryAdmin, self).__init__(*args, **kwargs)
        self.list_display_links = ('countrycode', )


admin.site.register(Country, CountryAdmin)


class PrefixAdmin(admin.ModelAdmin):
    search_fields = ('prefix', 'destination')
    list_display = ('prefix', 'destination', 'country_name', 'carrier_name')
    ordering = ('prefix', )
    # list_filter = ['country_name', 'carrier_name']

    def __init__(self, *args, **kwargs):
        super(PrefixAdmin, self).__init__(*args, **kwargs)
        # self.list_display_links = (None, )


admin.site.register(Prefix, PrefixAdmin)



#!/usr/bin/env python

import os
import sys
from django.test.runner import DiscoverRunner

os.environ.setdefault('DJANGO_SETTINGS_MODULE', 'tests.test_settings')
parent = os.path.dirname(os.path.dirname(os.path.dirname(os.path.abspath(__file__))))

sys.path.insert(0, parent)


def runtests():
    return DiscoverRunner().run_tests([
        # 'country_dialcode.CountryDialcodeAdminView',
        'tests.CountryDialcodeModel',
    ], verbosity=1, interactive=True)


if __name__ == '__main__':
    if runtests():
        sys.exit(1)



# -*- coding: utf-8 -*-

from builtins import object
import inspect


class Choice(object):

    class __metaclass__(type):
        def __init__(self, *args, **kwargs):
            self._data = []
            for name, value in inspect.getmembers(self):
                if not name.startswith('_') and not inspect.ismethod(value):
                    if isinstance(value, tuple) and len(value) > 1:
                        data = value
                    else:
                        pieces = [x.capitalize() for x in name.split('_')]
                        data = (value, ' '.join(pieces))
                    self._data.append(data)
                    setattr(self, name, data[0])

            self._hash = dict(self._data)

        def __iter__(self):
            for value, data in self._data:
                yield value, data

        @classmethod
        def get_value(self, key):
            return self._hash[key]



#!/usr/bin/env python
# -*- coding: utf-8 -*-
from os import path

from setuptools import setup, find_packages
import country_dialcode
import os
import re


def read(fname):
    try:
        return open(os.path.join(os.path.dirname(__file__), fname)).read()
    except IOError:
        return ''


def parse_requirements(file_name):
    requirements = []
    for line in open(file_name, 'r').read().split('\n'):
        if re.match(r'(\s*#)|(\s*$)', line):
            continue
        if re.match(r'\s*-e\s+', line):
            requirements.append(re.sub(r'\s*-e\s+.*#egg=(.*)$', r'\1', line))
        elif re.match(r'(\s*git)|(\s*hg)', line):
            pass
        else:
            requirements.append(line)
    return requirements


def parse_dependency_links(file_name):
    dependency_links = []
    for line in open(file_name, 'r').read().split('\n'):
        if re.match(r'\s*-[ef]\s+', line):
            dependency_links.append(re.sub(r'\s*-[ef]\s+', '', line))

    return dependency_links


with open(os.path.join(os.path.dirname(__file__), 'README.rst')) as readme:
    README = readme.read()

os.chdir(os.path.normpath(os.path.join(os.path.abspath(__file__), os.pardir)))

setup(
    name='django-country-dialcode-sb',
    version=country_dialcode.__version__,
    description='Django Application providing Dialcode and Countries code',
    long_description=README,
    long_description_content_type='text/x-rst',
    author='Belaid Arezqui',
    author_email='areski@gmail.com',
    url='http://github.com/Star2Billing/django-country-dialcode',
    zip_safe=False,
    packages=find_packages(exclude=["tests", "docs"]),
    package_data={
        "": [
            "fixtures/*",
        ]
    },
    #install_requires=parse_requirements('requirements.txt'),
    # dependency_links=parse_dependency_links('requirements.txt'),
    test_suite='country_dialcode.tests.runtests',
    include_package_data=True,
    license='MIT License',
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Environment :: Web Environment',
        'Framework :: Django',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.5',
        'Topic :: Software Development :: Libraries :: Python Modules'
    ],
)



from builtins import object
import os


BASE_DIR = os.path.dirname(__file__)

INSTALLED_APPS = (
    'django.contrib.auth',
    'django.contrib.sessions',
    'django.contrib.contenttypes',
    'django.contrib.admin',
    'country_dialcode',
)

DATABASES = {
    'default': {
        'ENGINE': 'django.db.backends.sqlite3',
    }
}

MIDDLEWARE_CLASSES = (
    'django.middleware.common.CommonMiddleware',
    'django.middleware.csrf.CsrfViewMiddleware',
)

ROOT_URLCONF = 'urls'
SECRET_KEY = 'secretkey'
SITE_ROOT = os.path.dirname(os.path.abspath(__file__))


# http://djangosnippets.org/snippets/646/
class InvalidVarException(object):
    def __mod__(self, missing):
        try:
            missing_str = ""
        except:
            missing_str = 'Failed to create string representation'
        raise Exception('Unknown template variable %r %s' % (missing, missing_str))

    def __contains__(self, search):
        if search == '%s':
            return True
        return False


TEMPLATE_DEBUG = True
TEMPLATE_STRING_IF_INVALID = InvalidVarException()



from django.apps import AppConfig
from django.utils.translation import ugettext_lazy as _


class CountryDialcodeConfig(AppConfig):
    name = 'country_dialcode'
    verbose_name = _('Country Dialcode')
